@@ -17,3 +17,7 @@ def readable_size(bytes):
         return "%.2f %s" % (bytes, lsize)
     else:
         return "%d %s" % (bytes, lsize)
+
+if not hasattr(__builtins__, "any"):
+    def any(iterable):
+        return bool(filter(None, iterable))
